"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jwt_1 = require("../../../utils/jwt");
const UserRepository_1 = require("../../repositories/UserRepository");
class Auth {
    async authenticate(req, res, next) {
        const authorization = String(req.headers.authorization);
        if (!authorization || !authorization.includes('Bearer')) {
            res.sendStatus(401);
            return;
        }
        const token = authorization === null || authorization === void 0 ? void 0 : authorization.slice(7);
        const payload = await jwt_1.default.verifyToken(token);
        if (!payload) {
            res.sendStatus(401);
            return;
        }
        const userId = payload.id;
        const userdata = await UserRepository_1.default.getUserDetail(userId);
        if (!userdata) {
            res.sendStatus(401);
            return;
        }
        req.userdata = userdata;
        next();
    }
    checkRoles(...roles) {
        return async (req, res, next) => {
            var _a;
            const userdata = req.userdata;
            const roleUser = (_a = userdata.role) === null || _a === void 0 ? void 0 : _a.slug;
            if (!roleUser) {
                res.sendStatus(403);
                return;
            }
            const isRoleValid = roles.includes(roleUser);
            if (!isRoleValid) {
                res.sendStatus(403);
                return;
            }
            next();
        };
    }
}
exports.default = new Auth();
