"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const User_1 = require("../models/User");
const Role_1 = require("../models/Role");
class UserRepository {
    createUser(payload) {
        return User_1.default.create(payload);
    }
    getUsers() {
        return User_1.default.findAll({
            attributes: ['id', 'roleId', 'firstName', 'lastName', 'email']
        });
    }
    getUserDetail(userId) {
        return User_1.default.findByPk(userId, {
            attributes: ['id', 'firstName', 'lastName', 'email'],
            include: [
                {
                    model: Role_1.default,
                    as: 'role',
                    required: false
                }
            ]
        });
    }
    getUserByEmail(email) {
        return User_1.default.findOne({
            where: {
                email: email
            }
        });
    }
    async updateUser(userId, payload) {
        const [updatedUserCount] = await User_1.default.update(payload, {
            where: {
                id: userId
            }
        });
        return !!updatedUserCount;
    }
    async deleteUser(userId) {
        const deletedUserCount = await User_1.default.destroy({
            where: {
                id: userId
            }
        });
        return !!deletedUserCount;
    }
}
exports.default = new UserRepository();
