"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bcrypt = require("bcrypt");
const UserRepository_1 = require("../repositories/UserRepository");
const jwt_1 = require("../../utils/jwt");
class AuthService {
    async login(payload) {
        const user = await UserRepository_1.default.getUserByEmail(payload.email);
        if (!user) {
            throw new Error('User not found');
        }
        const isValid = bcrypt.compareSync(payload.password, user.password);
        if (!isValid) {
            throw new Error('Email and Password is not match');
        }
        const token = await jwt_1.default.signToken(user.id);
        if (!token) {
            throw new Error('Invalid token');
        }
        return token;
    }
    async signUp(payload) {
        const user = await UserRepository_1.default.getUserByEmail(payload.email);
        if (user) {
            throw new Error('Email must be unique');
        }
        const hashedPassword = bcrypt.hashSync(payload.password, 5);
        return UserRepository_1.default.createUser(Object.assign(Object.assign({}, payload), { password: hashedPassword }));
    }
}
exports.default = new AuthService();
