"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const bcrypt = require("bcrypt");
const UserRepository_1 = require("../repositories/UserRepository");
class UserService {
    async createUser(payload) {
        const user = await UserRepository_1.default.getUserByEmail(payload.email);
        if (user) {
            throw new Error('Email must be unique');
        }
        const hashedPassword = bcrypt.hashSync(payload.password, 5);
        return UserRepository_1.default.createUser(Object.assign(Object.assign({}, payload), { password: hashedPassword }));
    }
    getUsers() {
        return UserRepository_1.default.getUsers();
    }
    async getUserDetail(userId) {
        const user = await UserRepository_1.default.getUserDetail(userId);
        if (!user) {
            throw new Error('User not found');
        }
        return user;
    }
    async updateUser(userId, payload) {
        const user = await UserRepository_1.default.getUserDetail(userId);
        if (!user) {
            throw new Error('User not found');
        }
        return UserRepository_1.default.updateUser(userId, payload);
    }
    async deleteUser(userId) {
        const user = await UserRepository_1.default.getUserDetail(userId);
        if (!user) {
            throw new Error('User not found');
        }
        return UserRepository_1.default.deleteUser(userId);
    }
}
exports.default = new UserService();
