"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createServer = void 0;
const express = require("express");
const compression = require("compression");
const cors = require("cors");
const swaggerUi = require("swagger-ui-express");
const v1_1 = require("./api/routes/v1");
const morgan_1 = require("./api/middlewares/morgan");
const appConfig_1 = require("./config/appConfig");
const swagger_1 = require("./utils/swagger");
const error_1 = require("./api/middlewares/handlers/error");
function createServer() {
    const app = express();
    const corsOption = {
        origin: '*',
        credentials: true
    };
    app.use(express.urlencoded({ extended: false }));
    app.use(express.json());
    app.use(cors(corsOption));
    app.use(compression());
    app.use(morgan_1.default);
    app.use(`/api/${appConfig_1.default.app.apiVersion}`, v1_1.default);
    if (appConfig_1.default.app.isDevelopment) {
        app.use(`/docs/${appConfig_1.default.app.apiVersion}`, swaggerUi.serve, swaggerUi.setup(swagger_1.specs));
    }
    app.use(error_1.default);
    return app;
}
exports.createServer = createServer;
